==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE39 (
   UNIQ_ID      VARCHAR (  10 )                 NOT NULL                                                /*  10 UNIQ番号     */
 , SEQNO        INTEGER             DEFAULT 0   NOT NULL                                                /*  20 表示順       */
 , SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  30 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR ( 100 )                 NOT NULL                                                /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      VARCHAR ( 100 )                 NOT NULL                                                /*  50 関連ｷｰ       */
 , SUFFIX       VARCHAR (  10 )                                                                         /*  60 拡張子       */
 , SYNAME       VARCHAR ( 200 )                                                                         /*  70 種別名称     */
 , SAVE_FOLDER  VARCHAR ( 300 )                                                                         /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR ( 300 )                                                                         /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR ( 300 )                                                                         /* 100 ｱｲｺﾝURL      */
 , ROLES        TEXT                                                                                    /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER             DEFAULT 0   NOT NULL                                                /* 120 閲覧制限数   */
 , DY_LMT       INTEGER             DEFAULT 0   NOT NULL                                                /* 130 閲覧期日     */
 , FGANGO       VARCHAR (   1 )     DEFAULT '0' NOT NULL                                                /* 140 暗号化FG     */
 , FGZIP        VARCHAR (   1 )     DEFAULT '0' NOT NULL                                                /* 150 圧縮FG       */
 , FILE_NAME    TEXT                                                                                    /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     TEXT                                                                                    /* 170 内容         */
 , FG_NEW       VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 180 最新FG       */
 , SIZE_FILE    INTEGER             DEFAULT 0   NOT NULL                                                /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    VARCHAR (  14 )                                                                         /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    VARCHAR (  10 )                                                                         /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     VARCHAR (  10 )                                                                         /* 220 登録画面ID   */
 , FGKOSHIN     VARCHAR (   1 )     DEFAULT '1'                                                         /* 230 変更許可FG   */
 , FGKOKAI      VARCHAR (   1 )     DEFAULT '1'                                                         /* 240 公開許可FG   */
 , SRCHKEY1     TEXT                                                                                    /* 250 検索ｷｰ1      */
 , SRCHKEY2     TEXT                                                                                    /* 270 検索ｷｰ2      */
 , SRCHKEY3     TEXT                                                                                    /* 280 検索ｷｰ3      */
 , SRCHKEY4     TEXT                                                                                    /* 290 検索ｷｰ4      */
 , SRCHKEY5     TEXT                                                                                    /* 300 検索ｷｰ5      */
 , SRCHKEY6     TEXT                                                                                    /* 310 検索ｷｰ6      */
 , SRCHKEY7     TEXT                                                                                    /* 320 検索ｷｰ7      */
 , SRCHKEY8     TEXT                                                                                    /* 330 検索ｷｰ8      */
 , SRCHKEY9     TEXT                                                                                    /* 340 検索ｷｰ9      */
 , SRCHKEY10    TEXT                                                                                    /* 350 検索ｷｰ10     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者       */
);

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:03                                            */
/****************************************************************************/

CREATE TABLE GE39 (
   UNIQ_ID      VARCHAR (  10 )                 NOT NULL                                                /*  10 UNIQ番号     */
 , SEQNO        INTEGER             DEFAULT 0   NOT NULL                                                /*  20 表示順       */
 , SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  30 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR ( 100 )                 NOT NULL                                                /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      VARCHAR ( 100 )                 NOT NULL                                                /*  50 関連ｷｰ       */
 , SUFFIX       VARCHAR (  10 )                                                                         /*  60 拡張子       */
 , SYNAME       VARCHAR ( 200 )                                                                         /*  70 種別名称     */
 , SAVE_FOLDER  VARCHAR ( 300 )                                                                         /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR ( 300 )                                                                         /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR ( 300 )                                                                         /* 100 ｱｲｺﾝURL      */
 , ROLES        TEXT                                                                                    /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER             DEFAULT 0   NOT NULL                                                /* 120 閲覧制限数   */
 , DY_LMT       INTEGER             DEFAULT 0   NOT NULL                                                /* 130 閲覧期日     */
 , FGANGO       VARCHAR (   1 )     DEFAULT '0' NOT NULL                                                /* 140 暗号化FG     */
 , FGZIP        VARCHAR (   1 )     DEFAULT '0' NOT NULL                                                /* 150 圧縮FG       */
 , FILE_NAME    TEXT                                                                                    /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     TEXT                                                                                    /* 170 内容         */
 , FG_NEW       VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 180 最新FG       */
 , SIZE_FILE    INTEGER             DEFAULT 0   NOT NULL                                                /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    VARCHAR (  14 )                                                                         /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    VARCHAR (  10 )                                                                         /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     VARCHAR (  10 )                                                                         /* 220 登録画面ID   */
 , FGKOSHIN     VARCHAR (   1 )     DEFAULT '1'                                                         /* 230 変更許可FG   */
 , FGKOKAI      VARCHAR (   1 )     DEFAULT '1'                                                         /* 240 公開許可FG   */
 , SRCHKEY1     TEXT                                                                                    /* 250 検索ｷｰ1      */
 , SRCHKEY2     TEXT                                                                                    /* 270 検索ｷｰ2      */
 , SRCHKEY3     TEXT                                                                                    /* 280 検索ｷｰ3      */
 , SRCHKEY4     TEXT                                                                                    /* 290 検索ｷｰ4      */
 , SRCHKEY5     TEXT                                                                                    /* 300 検索ｷｰ5      */
 , SRCHKEY6     TEXT                                                                                    /* 310 検索ｷｰ6      */
 , SRCHKEY7     TEXT                                                                                    /* 320 検索ｷｰ7      */
 , SRCHKEY8     TEXT                                                                                    /* 330 検索ｷｰ8      */
 , SRCHKEY9     TEXT                                                                                    /* 340 検索ｷｰ9      */
 , SRCHKEY10    TEXT                                                                                    /* 350 検索ｷｰ10     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 作成日時     */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者       */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者       */
);
